==> node-leveldown_5.4.1+dfsg.orig.tar.xz: leveldown-5.4.1/CONTRIBUTORS.md <==
# Contributors

| Name                       | GitHub                                                 | Social                                                                   |
| :------------------------- | :----------------------------------------------------- | :----------------------------------------------------------------------- |
| **Rod Vagg**               | [**@rvagg**](https://github.com/rvagg)                 | [**@rvagg@twitter**](https://twitter.com/rvagg)                          |
| **Lars-Magnus Skog**       | [**@ralphtheninja**](https://github.com/ralphtheninja) | [**@ralph@social.weho.st**](https://social.weho.st/@ralph)               |
| **Vincent Weevers**        | [**@vweevers**](https://github.com/vweevers)           | [**@vweevers@twitter**](https://twitter.com/vweevers)                    |
| **David Björklund**        | [**@kesla**](https://github.com/kesla)                 | [**@david_bjorklund@twitter**](https://twitter.com/david_bjorklund)      |
| **Julian Gruber**          | [**@juliangruber**](https://github.com/juliangruber)   | [**@juliangruber@twitter**](https://twitter.com/juliangruber)            |
| **Yichao 'Peak' Ji**       | [**@peakji**](https://github.com/peakji)               |                                                                          |
| **Mathias Buus**           | [**@mafintosh**](https://github.com/mafintosh)         | [**@mafintosh@twitter**](https://twitter.com/mafintosh)                  |
| **Dominic Tarr**           | [**@dominictarr**](https://github.com/dominictarr)     | [**@dominictarr@twitter**](https://twitter.com/dominictarr)              |
| **Christopher Jeffrey**    |                                                        |                                                                          |
| **Philippe Schommers**     |                                                        |                                                                          |
| **Raynos**                 |                                                        |                                                                          |
| **Gordon Hall**            | [**@bookchin**](https://github.com/bookchin)           |                                                                          |
| **Max Ogden**              | [**@maxogden**](https://github.com/maxogden)           | [**@maxogden@twitter**](https://twitter.com/maxogden)                    |
| **Geoff Greer**            | [**@ggreer**](https://github.com/ggreer)               |                                                                          |
| **Matteo Collina**         | [**@mcollina**](https://github.com/mcollina)           | [**@matteocollina@twitter**](https://twitter.com/matteocollina)          |
| **Meirion Hughes**         | [**@MeirionHughes**](https://github.com/MeirionHughes) |                                                                          |
| **Amine Mouafik**          | [**@kytwb**](https://github.com/kytwb)                 |                                                                          |
| **Braydon Fuller**         | [**@braydonf**](https://github.com/braydonf)           |                                                                          |
| **James Butler**           | [**@sandfox**](https://github.com/sandfox)             |                                                                          |
| **Oguz Bastemur**          | [**@obastemur**](https://github.com/obastemur)         | [**@obastemur@twitter**](https://twitter.com/obastemur)                  |
| **duralog**                |                                                        |                                                                          |
| **Aaron Bieber**           | [**@qbit**](https://github.com/qbit)                   |                                                                          |
| **Adam Bliss**             | [**@abliss**](https://github.com/abliss)               |                                                                          |
| **Alex Gentile**           | [**@agentilela**](https://github.com/agentilela)       |                                                                          |
| **Andre Staltz**           |                                                        |                                                                          |
| **Andrew Kelley**          | [**@andrewrk**](https://github.com/andrewrk)           |                                                                          |
| **Dean Landolt**           | [**@deanlandolt**](https://github.com/deanlandolt)     |                                                                          |
| **Huan LI**                | [**@zixia**](https://github.com/zixia)                 | [**@zixia@twitter**](https://twitter.com/zixia)                          |
| **Joyee Cheung**           | [**@joyeecheung**](https://github.com/joyeecheung)     | [**@joyeecheung@twitter**](https://twitter.com/joyeecheung)              |
| **Luandro**                | [**@luandro**](https://github.com/luandro)             |                                                                          |
| **Mark Wolfe**             | [**@wolfeidau**](https://github.com/wolfeidau)         |                                                                          |
| **Michael Ihde**           |                                                        |                                                                          |
| **Michael Nisi**           | [**@michaelnisi**](https://github.com/michaelnisi)     |                                                                          |
| **Nathan Shively-Sanders** | [**@sandersn**](https://github.com/sandersn)           |                                                                          |
| **No9**                    |                                                        |                                                                          |
| **Sharvil Nanavati**       | [**@sharvil**](https://github.com/sharvil)             |                                                                          |
| **Super-User**             |                                                        |                                                                          |
| **Thorsten Lorenz**        | [**@thlorenz**](https://github.com/thlorenz)           |                                                                          |
| **Tim Kuijsten**           | [**@timkuijsten**](https://github.com/timkuijsten)     | [**@timkuijsten@mastodon.social**](https://mastodon.social/@timkuijsten) |
| **flames of love**         |                                                        |                                                                          |
| **mscdex**                 | [**@mscdex**](https://github.com/mscdex)               |                                                                          |

==> node-leveldown_5.6.0+dfsg.orig.tar.xz: leveldown-5.6.0/CONTRIBUTORS.md <==
# Contributors

| Name                       | GitHub                                                 | Social                                                                   |
| :------------------------- | :----------------------------------------------------- | :----------------------------------------------------------------------- |
| **Rod Vagg**               | [**@rvagg**](https://github.com/rvagg)                 | [**@rvagg@twitter**](https://twitter.com/rvagg)                          |
| **Lars-Magnus Skog**       | [**@ralphtheninja**](https://github.com/ralphtheninja) | [**@ralph@social.weho.st**](https://social.weho.st/@ralph)               |
| **Vincent Weevers**        | [**@vweevers**](https://github.com/vweevers)           | [**@vweevers@twitter**](https://twitter.com/vweevers)                    |
| **David Björklund**        | [**@kesla**](https://github.com/kesla)                 | [**@david_bjorklund@twitter**](https://twitter.com/david_bjorklund)      |
| **Julian Gruber**          | [**@juliangruber**](https://github.com/juliangruber)   | [**@juliangruber@twitter**](https://twitter.com/juliangruber)            |
| **Yichao 'Peak' Ji**       | [**@peakji**](https://github.com/peakji)               |                                                                          |
| **Mathias Buus**           | [**@mafintosh**](https://github.com/mafintosh)         | [**@mafintosh@twitter**](https://twitter.com/mafintosh)                  |
| **Dominic Tarr**           | [**@dominictarr**](https://github.com/dominictarr)     | [**@dominictarr@twitter**](https://twitter.com/dominictarr)              |
| **Christopher Jeffrey**    |                                                        |                                                                          |
| **Philippe Schommers**     |                                                        |                                                                          |
| **Raynos**                 |                                                        |                                                                          |
| **Gordon Hall**            | [**@bookchin**](https://github.com/bookchin)           |                                                                          |
| **Max Ogden**              | [**@maxogden**](https://github.com/maxogden)           | [**@maxogden@twitter**](https://twitter.com/maxogden)                    |
| **Geoff Greer**            | [**@ggreer**](https://github.com/ggreer)               |                                                                          |
| **Matteo Collina**         | [**@mcollina**](https://github.com/mcollina)           | [**@matteocollina@twitter**](https://twitter.com/matteocollina)          |
| **Meirion Hughes**         | [**@MeirionHughes**](https://github.com/MeirionHughes) |                                                                          |
| **Amine Mouafik**          | [**@kytwb**](https://github.com/kytwb)                 |                                                                          |
| **Braydon Fuller**         | [**@braydonf**](https://github.com/braydonf)           |                                                                          |
| **duralog**                |                                                        |                                                                          |
| **James Butler**           | [**@sandfox**](https://github.com/sandfox)             |                                                                          |
| **Oguz Bastemur**          | [**@obastemur**](https://github.com/obastemur)         | [**@obastemur@twitter**](https://twitter.com/obastemur)                  |
| **Aaron Bieber**           | [**@qbit**](https://github.com/qbit)                   |                                                                          |
| **Adam Bliss**             | [**@abliss**](https://github.com/abliss)               |                                                                          |
| **Alex Gentile**           | [**@agentilela**](https://github.com/agentilela)       |                                                                          |
| **Andre Staltz**           |                                                        |                                                                          |
| **Andrew Kelley**          | [**@andrewrk**](https://github.com/andrewrk)           |                                                                          |
| **Christian Bundy**        |                                                        |                                                                          |
| **Dean Landolt**           | [**@deanlandolt**](https://github.com/deanlandolt)     |                                                                          |
| **flames of love**         |                                                        |                                                                          |
| **Huan LI**                | [**@zixia**](https://github.com/zixia)                 | [**@zixia@twitter**](https://twitter.com/zixia)                          |
| **Joyee Cheung**           | [**@joyeecheung**](https://github.com/joyeecheung)     | [**@joyeecheung@twitter**](https://twitter.com/joyeecheung)              |
| **Luandro**                | [**@luandro**](https://github.com/luandro)             |                                                                          |
| **Mark Wolfe**             | [**@wolfeidau**](https://github.com/wolfeidau)         |                                                                          |
| **Michael Ihde**           |                                                        |                                                                          |
| **Michael Nisi**           | [**@michaelnisi**](https://github.com/michaelnisi)     |                                                                          |
| **mscdex**                 | [**@mscdex**](https://github.com/mscdex)               |                                                                          |
| **Nathan Shively-Sanders** | [**@sandersn**](https://github.com/sandersn)           |                                                                          |
| **No9**                    |                                                        |                                                                          |
| **Sharvil Nanavati**       | [**@sharvil**](https://github.com/sharvil)             |                                                                          |
| **Super-User**             |                                                        |                                                                          |
| **Thorsten Lorenz**        | [**@thlorenz**](https://github.com/thlorenz)           |                                                                          |
| **Tim Kuijsten**           | [**@timkuijsten**](https://github.com/timkuijsten)     | [**@timkuijsten@mastodon.social**](https://mastodon.social/@timkuijsten) |
